#!/usr/bin/env python

import os
import time
from profilemanager import ProfileManager

# Get the path to the test profiles.ini file:
from pkg_resources import resource_filename
profiles_dir = os.path.join('tests', 'profiles')
path = os.path.join(profiles_dir, 'profiles.ini')
profiles = resource_filename('profilemanager', path)
profiles_dir = resource_filename('profilemanager', profiles_dir)
assert os.path.exists(profiles), '%s does not exist' % profiles
assert os.path.exists(profiles_dir), '%s does not exist' % profiles_dir

# Instatiate a ProfileManager:
manager = ProfileManager(profiles)

# Remove any profiles that didn't get cleaned up:
profiles_dict = manager.profiles_dict()
for profile in profiles_dict:
  manager.remove(profile)
assert os.listdir(profiles_dir) == ['profiles.ini'], 'profiles_dir isnt empty except profiles.ini'
assert file(profiles).read().strip() == '[General]', 'profiles.ini isnt nearly empty'
    
# Create a new profile:
profiledir = manager.new('testprofile')
assert profiledir.endswith('.testprofile'), 'profiledir should end with testprofile, instead it is %s' % profiledir
assert manager.list() == ['testprofile']

# Clone the profile:
manager.clone('testprofile', 'cloneprofile')
assert sorted(manager.list()) == ['cloneprofile', 'testprofile']
manager.remove('cloneprofile')

# Backup the profile
manager.backup('testprofile')
backups = manager.backups('testprofile')
assert len(backups) == 1, "Expected one backup, instead got %d" % len(backups)
assert backups[0][0].startswith('testprofile')
manager.restore('testprofile')
manager.restore('testprofile', delete=True)
backups = manager.backups('testprofile')
assert not backups
# TODO: test the backup with a populated profile

# Test dated backups
manager.backup('testprofile')
old_backups = manager.backups('testprofile')[0]
old_time = int(time.time())
time.sleep(3)
manager.backup('testprofile')
# TODO: test with alternate forms of date

# Cleanup:
manager.remove('testprofile')
assert manager.list() == []
f = file(profiles, 'w')
print >> f, '[General]'
